﻿using Models;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Tests
{
    public class ManagerTest
    {
        [Fact]
        public void Manager_Creation_Et_Verification()
        {
            
            var manager = new Manager();

            // Assert
            Assert.Empty(manager.Admins);
            Assert.Empty(manager.Utilisateurs);
            Assert.Empty(manager.TopRatedGames);
            Assert.Empty(manager.ListJeuxAffiches);
            Assert.Empty(manager.ListJeux);
            Assert.Null(manager.ConnectedUser);
        }

        [Fact]
        public void Manager_AddJeux()
        {
            
            var manager = new Manager();
            var jeu = new Jeu("Un Jeu", "Description", "1 Janvier 2023", "PC", "Studio", "Editeur", 4.5, 1000, "Action", "test_image.png");

           
            manager.AddJeux(jeu);

            // Assert
            Assert.Single(manager.ListJeux);
            Assert.Contains(jeu, manager.ListJeux);
        }

        [Fact]
        public void Manager_AddAdmin()
        {
            
            var manager = new Manager();
            var admin = new Admin("admin@example.com", "admin", "password");

            
            manager.AddAdmin(admin);

            // Assert
            Assert.Single(manager.Admins);
            Assert.Contains(admin, manager.Admins);
        }

        [Fact]
        public void Manager_AddUtilisateur()
        {
            
            var manager = new Manager();
            var utilisateur = new Utilisateur("test@example.com", "test", "password");

            
            manager.AddUtilisateur(utilisateur);

            // Assert
            Assert.Single(manager.Utilisateurs);
            Assert.Contains(utilisateur, manager.Utilisateurs);
        }

        [Fact]
        public void Manager_ChargerDonnees()
        {
            // Arrange
            var manager = new Manager();
            var jeux = new ObservableCollection<Jeu>()
            {
                new Jeu("Un Jeu", "Description", "1 Janvier 2023", "PC", "Studio", "Editeur", 4.5, 1000, "Action", "test_image.png"),
                new Jeu("Un autre Jeu", "Une autre description", "12 Janvier 2023", "PS5", "Studio", "Autre Editeur", 3.8, 500, "Aventure", "test_image.png")
            };
            var admins = new List<Admin>()
            {
                new Admin("admin1@example.com", "admin1", "password1"),
                new Admin("admin2@example.com", "admin2", "password2")
            };
            var utilisateurs = new List<Utilisateur>()
            {
                new Utilisateur("user1@example.com", "user1", "password1"),
                new Utilisateur("user2@example.com", "user2", "password2")
            };

            
            manager.ListJeux = jeux;
            manager.Admins = admins;
            manager.Utilisateurs = utilisateurs;

            manager.ChargerDonnees();

            // Assert
            Assert.Equal(jeux, manager.ListJeux);
            Assert.Equal(admins, manager.Admins);
            Assert.Equal(utilisateurs, manager.Utilisateurs);
        }

        [Fact]
        public void Manager_SauvegardeDonnees()
        {
            
            var manager = new Manager();
            var jeux = new ObservableCollection<Jeu>()
            {
                new Jeu("Un Jeu", "Description", "1 Janvier 2023", "PC", "Studio", "Editeur", 4.5, 1000, "Action", "test_image.png"),
                new Jeu("Un autre Jeu", "Une autre description", "12 Janvier 2023", "PS5", "Studio", "Autre Editeur", 3.8, 500, "Aventure", "test_image.png")
            };
            var admins = new List<Admin>()
            {
                new Admin("admin1@example.com", "adminuser1", "password1"),
                new Admin("admin2@example.com", "adminuser2", "password2")
            };
            var utilisateurs = new List<Utilisateur>()
            {
                new Utilisateur("user1@example.com", "user1", "password1"),
                new Utilisateur("user2@example.com", "user2", "password2")
            };

            
            manager.ListJeux = jeux;
            manager.Admins = admins;
            manager.Utilisateurs = utilisateurs;

            manager.SauvegardeDonnees();

            // Assert
            Assert.True(true); // Vérifie qu'il n'y a aucune exception de levée
        }
    }
}
